unmonitor: Stop monitoring variables

Description Usage Arguments

View source: R/varmonitor.R

Description

This function stops the monitoring of a variable being monitored and removes it from the active browser window or RStudio viewer pane.

Usage

1

Arguments

...

variables to monitor

list

optional character vector of variable names to monitor


vankesteren/varmonitor documentation built on Nov. 5, 2019, 2:48 p.m.