This function stops the monitoring of a variable being monitored and removes it from the active browser window or RStudio viewer pane.
1 |
... |
variables to monitor |
list |
optional character vector of variable names to monitor |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.